/**
 * Syntax.js
 */
var Syntax = (function() {

	'use strict';

	/**
	 * Adds syntax highlighting to JSON snippet.
	 * @param  {String} snippet A JSON string.
	 * @return {String}         String with added classes for syntax highlighting.
	 */
	function highlightJSON( snippet ) {

			// Replace &, <, and > chars with their htmlentities
			snippet = snippet
						.replace( /&/g, '&amp;' )
						.replace( /</g, '&lt;' )
						.replace( />/g, '&gt;' );

			// Wrap data types with appropriate spans for syntax highlighting
			snippet = snippet.replace( /("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g, function( match ) {

				var cls = 'number'; // Number

				if ( /^"/.test( match ) ) { // Wrapped with ""
					if ( /:$/.test( match ) ) { // Key
						cls = 'key';
					} else { // String
						cls = 'string';
					}
				} else if ( /true|false/.test( match ) ) { // Boolean
					cls = 'boolean';
				} else if ( /null/.test( match ) ) { // Null
					cls = 'null';
				}

				return '<span class="' + cls + '">' + match + '</span>';

			});

			return snippet;

	}

	/**
	 * Wraps the provided snippet with <pre> tags for proper formatting and spacing.
	 * @param  {String} snippet A string containing a snippet of code.
	 * @return {String}         The string wrapped with <pre> tags.
	 */
	function wrapWithPreTags( snippet ) {

		snippet = '<pre>' + snippet + '</pre>';

		return snippet;

	}

	return {

		/**
		 * Highlights code snippets based on the specified syntax.
		 * @param  {String} syntax  String representing the syntax of the provided snippet.
		 * @param  {String} snippet A code snippet in string form.
		 * @return {String}         A string with added highlighting or a message about unsupported
		 * syntax.
		 */
		highlight: function( syntax, snippet ) {

			switch ( syntax ) {
				case 'json':
					return wrapWithPreTags( highlightJSON( snippet ) );
					break;
				default:
					return 'Your current syntax is not supported. Try using the following syntax: \'json\'';
			}
		
		}

	};

})();